@@ -134,6 +134,7 @@ $c->locale_path = '../locale';
 $c->base_url = preg_replace('#/[^/]+\.php.*$#', '', $_SERVER['SCRIPT_NAME']);
 $c->base_directory = preg_replace('#/[^/]*$#', '', $_SERVER['DOCUMENT_ROOT']);
 $c->default_privileges = array('read-free-busy', 'schedule-deliver');
+$c->list_everyone = true;
 
 $c->enable_auto_schedule = true;
 
@@ -286,8 +287,8 @@ if ( function_exists('awl_set_locale') ) {
 *
 */
 $c->code_version = 0;
-$c->want_awl_version = '0.61';
-$c->version_string = '1.1.9.3'; // The actual version # is replaced into that during the build /release process
+$c->want_awl_version = '0.62';
+$c->version_string = '1.1.10'; // The actual version # is replaced into that during the build /release process
 if ( isset($c->version_string) && preg_match( '/(\d+)\.(\d+)\.(\d+)(.*)/', $c->version_string, $matches) ) {
   $c->code_major = $matches[1];
   $c->code_minor = $matches[2];
