@@ -51,7 +51,6 @@ if ( count($qry_filters) == 0 ) {
   $qry_filters = false;
 }
 
-$qry_limit = -1; // everything
 $qry_filters_combination='OR';
 if ( is_array($qry_filters) ) {
   $filters_parent = $xmltree->GetPath('/urn:ietf:params:xml:ns:carddav:addressbook-query/urn:ietf:params:xml:ns:carddav:filter');
@@ -60,11 +59,12 @@ if ( is_array($qry_filters) ) {
   if ( $filters_parent->GetAttribute("test") == 'allof' ) {
     $qry_filters_combination='AND';
   }
+}
 
-  $limits = $xmltree->GetPath('/urn:ietf:params:xml:ns:carddav:addressbook-query/urn:ietf:params:xml:ns:carddav:limit/urn:ietf:params:xml:ns:carddav:nresults');
-  if ( count($limits) == 1) {
-    $qry_limit = intval($limits[0]->GetContent());
-  }
+$qry_limit = -1; // everything
+$limits = $xmltree->GetPath('/urn:ietf:params:xml:ns:carddav:addressbook-query/urn:ietf:params:xml:ns:carddav:limit/urn:ietf:params:xml:ns:carddav:nresults');
+if ( count($limits) == 1) {
+  $qry_limit = intval($limits[0]->GetContent());
 }
 
 /**
@@ -109,13 +109,20 @@ function SqlFilterCardDAV( $filter, $components, $property = null, $parameter =
   $sql = "";
   $params = array();
 
+  // a prop-filter without an actual filter rule means we simply need to ensure the property exists
+  if ( !is_object($filter) ) {
+    if ( empty($property) ) return false;
+    $sql .= $property . ' IS NOT NULL';
+    return array( 'sql' => $sql, 'params' => $params );
+  }
+
   $tag = $filter->GetNSTag();
   dbg_error_log("cardquery", "Processing $tag into SQL - %d, '%s', %d\n", count($components), $property, isset($parameter) );
 
   $not_defined = "";
   switch( $tag ) {
     case 'urn:ietf:params:xml:ns:carddav:is-not-defined':
-      $sql .= $property . 'IS NULL';
+      $sql .= $property . ' IS NULL';
       break;
 
     case 'urn:ietf:params:xml:ns:carddav:text-match':
@@ -144,7 +151,7 @@ function SqlFilterCardDAV( $filter, $components, $property = null, $parameter =
           $search = $search.'%';
           break;
         case 'ends-with':
-          $search = $search.'%';
+          $search = '%'.$search;
           break;
         case 'contains':
         default:
@@ -156,7 +163,7 @@ function SqlFilterCardDAV( $filter, $components, $property = null, $parameter =
       $params[$pname] = $search;
 
       $negate = $filter->GetAttribute("negate-condition");
-      $negate = ( (isset($negate) && strtolower($negate) ) == "yes" ) ? "NOT " : "";
+      $negate = ( isset($negate) && strtolower($negate) == "yes" ) ? "NOT " : "";
       dbg_error_log("cardquery", " text-match: (%s%s %s '%s') ", $negate, $property, $comparison, $search );
       $sql .= sprintf( "(%s%s %s $pname)", $negate, $property, $comparison );
       break;
@@ -270,7 +277,8 @@ if ( ! $target_collection->IsAddressbook() ) {
 */
 
 $params = array();
-$where = ' WHERE caldav_data.collection_id = ' . $target_collection->resource_id();
+$where_collection = ' WHERE caldav_data.collection_id = ' . $target_collection->resource_id();
+$where = '';
 if ( is_array($qry_filters) ) {
   dbg_log_array( 'cardquery', 'qry_filters', $qry_filters, true );
 
@@ -311,7 +319,7 @@ if ( $need_post_filter && ( $qry_filters_combination == 'OR' )) {
   $post_filters = $qry_filters;
 }
 
-$sql = 'SELECT * FROM caldav_data INNER JOIN addressbook_resource USING(dav_id)'. $where;
+$sql = 'SELECT * FROM caldav_data INNER JOIN addressbook_resource USING(dav_id)'. $where_collection . $where;
 if ( isset($c->strict_result_ordering) && $c->strict_result_ordering ) $sql .= " ORDER BY dav_id";
 $qry = new AwlQuery( $sql, $params );
 if ( $qry->Exec("cardquery",__LINE__,__FILE__) && $qry->rows() > 0 ) {
